@@ -96,17 +96,16 @@ class Defaults(object):
 		# overwrite.
 		overwrite=False,
 	):
-		if sudo or cl1.argument_present("--sudo"): sudo = "sudo "
-		else: sudo = ""
 		l_alias = cl1.get_argument("--create-alias", required=False)
 		present = "--create-alias" in sys.argv and l_alias == alias
 		base = f"/usr/local/bin"
 		if not os.path.exists(base):
 			base = f"/usr/bin/"
 		path = f"{base}/{alias}"
-		if cl1.argument_present("--force") or cl1.argument_present("--forced") or overwrite or present or not os.path.exists(path):
+		if ((cl1.argument_present("--force") or cl1.argument_present("--forced") or overwrite) and present) or (present or not os.path.exists(path)):
 			if l_alias != None: alias = l_alias
 			#file = f"""package={executable}/\nargs=""\nfor var in "$@" ; do\n   	if [ "$args" == "" ] ; then\n   		args=$var\n   	else\n   		args=$args" "$var\n   	fi\ndone\npython3 $package $args\n"""
+			sudo = Formats.Boolean("--sudo" in sys.argv).convert(true="sudo ",false="")
 			file = f"""#!/usr/bin/env python3\nimport os, sys\npackage="{executable}"\nsys.argv.pop(0)\narguments = sys.argv\ns = ""\nfor i in arguments:\n	if s == "": \n		if " " in i: s = "'"+i+"'"\n		else: s = i\n	else: \n		if " " in i: s += " '"+i+"'"\n		else: s += " "+i\nif os.path.exists("/usr/bin/python3"): os.system("/usr/bin/python3 "+package+" "+s)\nelse:  os.system("python3 "+package+" "+s)"""
 			os.system(f"{sudo}touch {path}")
 			os.system(f"{sudo}chmod +x {path}")
